@@ -464,9 +464,7 @@ void Frame_Glom::on_menu_developer_developer(const Glib::RefPtr<Gtk::RadioAction
       bool test = true;
 
       if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
-      {
-        test = Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
-      }
+        Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
 
       if(test)
       {
@@ -846,7 +844,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
         const bool initial_password_provided = connection_request_initial_password(user, password);
         bool added = false;
         if(initial_password_provided)
-          added = DbUtils::add_user(document, user, password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+          added = add_user(user, password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
 
         if(initial_password_provided && added)
         {
@@ -896,7 +894,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
           const bool reowned = set_database_owner_user(connectionpool->get_user());
           bool removed = false;
           if(reowned)
-            removed = DbUtils::remove_user(default_user);
+            removed = remove_user(default_user);
 
           if(!removed)
           {
@@ -904,12 +902,6 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
             //Try to revoke it instead.
             //TODO: Discover how to make remove_user() succeed.
             disabled = disable_user(default_user);
-            if(disabled)
-            {
-              //This message should be reassuring if the user sees a previous error
-              //about the default user not being removed.
-              std::cout << G_STRFUNC << ": The default user could not be removed, but it has been disabled." << std::endl;
-            }
           }
 
           if(!reowned || !(removed || disabled))
@@ -950,7 +942,7 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
         Glib::ustring default_password;
         const Glib::ustring default_user = Privs::get_default_developer_user_name(default_password);
 
-        const bool added = DbUtils::add_user(document, default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+        const bool added = add_user(default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
         if(!added)
         {
            shared = true;
@@ -2330,12 +2322,9 @@ void Frame_Glom::do_print_layout(const Glib::ustring& print_layout_name, bool pr
     return;
   }
   
-  //TODO: When expanding items, avoid the page gaps that the print layout's design
+  //TODO: When expandingt items, avoid the page gaps that the print layout's designed
   //has added.  
   const FoundSet found_set = m_Notebook_Data.get_found_set_details();
-  //Note that found_set.m_where_clause could be empty if there are no records yet,
-  //and that is acceptable if this is for a print preview while designing the print layout. 
-  
   PrintLayoutUtils::do_print_layout(print_layout, found_set, 
     preview, document, false /* do not avoid print margins */, transient_for);
 }
