@@ -21,7 +21,7 @@
 #ifndef GLOM_BACKEND_POSTGRES_H
 #define GLOM_BACKEND_POSTGRES_H
 
-#include <libgdamm.h>
+#include <libgdamm/connection.h>
 #include <libglom/connectionpool_backends/backend.h>
 
 #include <libglom/libglom_config.h>
@@ -51,12 +51,13 @@ public:
 
   virtual bool convert_backup(const SlotProgress& slot_progress, const std::string& base_directory, const Glib::ustring& username, const Glib::ustring& password, const Glib::ustring& database_name);
 
-  static std::string get_path_to_postgres_executable(const std::string& program);
+  /** Return the quoted path to the specified PostgreSQL utility.
+   */
+  static std::string get_path_to_postgres_executable(const std::string& program, bool quoted = true);
 
 
 
 private:
-  virtual Field::sql_format get_sql_format() const;
   virtual bool supports_remote_access() const;
   virtual Gnome::Gda::SqlOperatorType get_string_find_operator() const;
   virtual const char* get_public_schema_name() const;
@@ -69,7 +70,7 @@ protected:
   /** Attempt to connect to the database with the specified criteria.
    * @throws An ExceptionConnection if the correction failed.
    */ 
-  Glib::RefPtr<Gnome::Gda::Connection> attempt_connect(const Glib::ustring& port, const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password);
+  Glib::RefPtr<Gnome::Gda::Connection> attempt_connect(const Glib::ustring& port, const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, bool fake_connection);
 
  std::string get_self_hosting_path(bool create = false, const std::string& child_directory = std::string());
 
