@@ -24,7 +24,7 @@
 #include <libglom/data_structure/layout/usesrelationship.h>
 #include <libglom/data_structure/numeric_format.h>
 #include <libglom/data_structure/relationship.h>
-#include <libglom/sharedptr.h>
+#include <libglom/data_structure/choicevalue.h>
 #include <libgdamm/value.h>
 #include <list>
 
@@ -55,10 +55,20 @@ public:
   bool get_has_custom_choices() const;
   void set_has_custom_choices(bool val = true);
 
-  typedef std::list<Gnome::Gda::Value> type_list_values;
+  typedef std::list< sharedptr<ChoiceValue> > type_list_values;
   virtual type_list_values get_choices_custom() const;
   virtual void set_choices_custom(const type_list_values& choices);
 
+  /** Get the original text that corresponds to the translated choice for the 
+   * current locale.
+   */
+  Glib::ustring get_custom_choice_original_for_translated_text(const Glib::ustring& text) const;
+
+  /** Get the translated choice text, for the 
+   * current locale, that corresponds to the original text .
+   */
+  Glib::ustring get_custom_choice_translated(const Glib::ustring& original_text) const;
+
   typedef std::pair< sharedptr<const LayoutItem_Field>, bool /* is_ascending */> type_pair_sort_field;
   typedef std::list<type_pair_sort_field> type_list_sort_fields;
 
