@@ -59,7 +59,7 @@ public:
 
   /** Get the title's original (non-translated, usually English) text.
    */
-  Glib::ustring get_title_original() const;
+  virtual Glib::ustring get_title_original() const;
 
 
   /** Set the title's translation for the current locale.
@@ -98,10 +98,11 @@ public:
      TRANSLATABLE_TYPE_TABLE,
      TRANSLATABLE_TYPE_BUTTON,
      TRANSLATABLE_TYPE_TEXTOBJECT,
-     TRANSLATABLE_TYPE_IMAGEOBJECT
+     TRANSLATABLE_TYPE_IMAGEOBJECT,
+     TRANSLATABLE_TYPE_CHOICEVALUE
    };
 
-  enumTranslatableItemType get_translatable_item_type();
+  enumTranslatableItemType get_translatable_item_type() const;
 
   //Direct access, for performance:
   const type_map_locale_to_translations& _get_translations_map() const;
