@@ -24,7 +24,6 @@
 #include <libglom/connectionpool_backends/postgres_central.h>
 #include <libglom/standard_table_prefs_fields.h>
 #include <libglom/privs.h>
-#include <libglom/data_structure/parameternamegenerator.h>
 #include <libglom/utils.h>
 #include <libgdamm/value.h>
 #include <libgdamm/metastore.h>
@@ -422,7 +421,6 @@ void set_database_preferences(Document* document, const SystemPrefs& prefs)
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
   builder->set_table(GLOM_STANDARD_TABLE_PREFS_TABLE_NAME);
   builder->add_field_value(GLOM_STANDARD_TABLE_PREFS_FIELD_NAME, prefs.m_name);
-  builder->add_field_value(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_NAME, prefs.m_org_name);
   builder->add_field_value(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET, prefs.m_org_address_street);
   builder->add_field_value(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_STREET2, prefs.m_org_address_street2);
   builder->add_field_value(GLOM_STANDARD_TABLE_PREFS_FIELD_ORG_ADDRESS_TOWN, prefs.m_org_address_town);
@@ -652,15 +650,16 @@ bool add_groups_from_document(Document* document)
   {
     const GroupInfo& group = *iter;
     const Glib::ustring name = group.get_name();
-    //std::cout << G_STRFUNC << ": DEBUG: group=" << name << std::endl;
 
     //See if the group exists in the database:
     type_vec_strings::const_iterator iterFind = std::find(database_groups.begin(), database_groups.end(), name);
     if(!name.empty() && iterFind == database_groups.end())
     {
-      if(!add_group(document, name, group.m_developer))
+      const Glib::ustring query = build_query_create_group(name, group.m_developer);
+      const bool test = query_execute_string(query);
+      if(!test)
       {
-        std::cerr << G_STRFUNC << ": add_group() failed when adding the group with name=" << name << std::endl;
+        std::cerr << G_STRFUNC << ": CREATE GROUP failed when adding the group with name=" << name << std::endl;
         return false;
       }
     }
@@ -960,6 +959,89 @@ type_vec_fields get_fields_for_table_from_database(const Glib::ustring& table_na
   return result;
 }
 
+//TODO: This is very inefficient, because it is called so often. Just update the document with whatever is really in the database:
+type_vec_fields get_fields_for_table(const Document* document, const Glib::ustring& table_name, bool including_system_fields)
+{
+  //Get field definitions from the database:
+  type_vec_fields fieldsDatabase = get_fields_for_table_from_database(table_name, including_system_fields);
+
+  if(!document)
+  {
+    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    return fieldsDatabase; //This should never happen.
+  }
+
+  type_vec_fields result;
+
+  type_vec_fields fieldsDocument = document->get_table_fields(table_name);
+
+  //Look at each field in the database:
+  for(type_vec_fields::iterator iter = fieldsDocument.begin(); iter != fieldsDocument.end(); ++iter)
+  {
+    sharedptr<Field> field = *iter;
+    const Glib::ustring field_name = field->get_name();
+
+    //Get the field info from the database:
+    //This is in the document as well, but it _might_ have changed.
+    type_vec_fields::const_iterator iterFindDatabase = 
+      std::find_if(fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>(field_name));
+
+    if(iterFindDatabase != fieldsDatabase.end() ) //Ignore fields that don't exist in the database anymore.
+    {
+      Glib::RefPtr<Gnome::Gda::Column> field_info_document = field->get_field_info();
+
+      //Update the Field information that _might_ have changed in the database.
+      Glib::RefPtr<Gnome::Gda::Column> field_info = (*iterFindDatabase)->get_field_info();
+
+      //libgda does not tell us whether the field is auto_incremented, so we need to get that from the document.
+      field_info->set_auto_increment( field_info_document->get_auto_increment() );
+
+      //libgda does not tell us whether the field is auto_incremented, so we need to get that from the document.
+      //TODO_gda:field_info->set_primary_key( field_info_document->get_primary_key() );
+
+      //libgda does yet tell us correct default_value information so we need to get that from the document.
+      field_info->set_default_value( field_info_document->get_default_value() );
+
+      field->set_field_info(field_info);
+
+      result.push_back(*iter);
+    }
+  }
+
+  //Add any fields that are in the database, but not in the document:
+  for(type_vec_fields::iterator iter = fieldsDatabase.begin(); iter != fieldsDatabase.end(); ++iter)
+  {
+    const Glib::ustring field_name = (*iter)->get_name();
+
+    //Look in the result so far:
+    type_vec_fields::const_iterator iterFind = std::find_if(result.begin(), result.end(), predicate_FieldHasName<Field>(field_name));
+
+    //Add it if it is not there:
+    if(iterFind == result.end() )
+      result.push_back(*iter);
+  }
+
+  return result;
+}
+
+sharedptr<Field> get_fields_for_table_one_field(const Document* document, const Glib::ustring& table_name, const Glib::ustring& field_name)
+{
+  //Initialize output parameter:
+  sharedptr<Field> result;
+
+  if(field_name.empty() || table_name.empty())
+    return result;
+
+  type_vec_fields fields = get_fields_for_table(document, table_name); //TODO_Performance
+  type_vec_fields::iterator iter = std::find_if(fields.begin(), fields.end(), predicate_FieldHasName<Field>(field_name));
+  if(iter != fields.end()) //TODO: Handle error?
+  {
+    return *iter;
+  }
+
+  return sharedptr<Field>();
+}
+
 //TODO_Performance: Avoid calling this so often.
 //TODO: Put this in libgdamm.
 type_vec_strings get_table_names_from_database(bool ignore_system_tables)
@@ -984,15 +1066,11 @@ type_vec_strings get_table_names_from_database(bool ignore_system_tables)
       std::cerr << G_STRFUNC << ": Error: " << ex.what() << std::endl;
     }
 
-    if(!data_model_tables)
-    {
-      std::cerr << G_STRFUNC << ": libgda returned an empty tables GdaDataModel for the database." << std::endl;
-    }
-    else if(data_model_tables->get_n_columns() <= 0)
+    if(data_model_tables && (data_model_tables->get_n_columns() == 0))
     {
       std::cerr << G_STRFUNC << ": libgda reported 0 tables for the database." << std::endl;
     }
-    else
+    else if(data_model_tables)
     {
       //std::cout << "debug: data_model_tables refcount=" << G_OBJECT(data_model_tables->gobj())->ref_count << std::endl;
       const int rows = data_model_tables->get_n_rows();
@@ -1048,7 +1126,7 @@ bool get_table_exists_in_database(const Glib::ustring& table_name)
 {
   //TODO_Performance
 
-  type_vec_strings tables = get_table_names_from_database();
+  const type_vec_strings tables = get_table_names_from_database();
   type_vec_strings::const_iterator iterFind = std::find(tables.begin(), tables.end(), table_name);
   return (iterFind != tables.end());
 }
@@ -1936,167 +2014,6 @@ Glib::ustring build_query_add_user_to_group(const Glib::ustring& group, const Gl
   return "ALTER GROUP " + escape_sql_id(group) + " ADD USER " + escape_sql_id(user);
 }
 
-static Glib::ustring build_query_add_user(const Glib::ustring& user, const Glib::ustring& password, bool superuser)
-{
-  if(user.empty())
-  {
-    std::cerr << G_STRFUNC << ": user is empty" << std::endl;
-  }
-
-  if(password.empty())
-  {
-    std::cerr << G_STRFUNC << ": password is empty" << std::endl;
-  }
-
-  //Note that ' around the user fails, so we use ".
-  Glib::ustring strQuery = "CREATE USER " + DbUtils::escape_sql_id(user) + " PASSWORD '" + password + "'" ; //TODO: Escape the password.
-  if(superuser)
-    strQuery += " SUPERUSER CREATEDB CREATEROLE"; //Because SUPERUSER is not "inherited" from groups to members.
-
-  return strQuery;
-}
-
-bool add_user(const Document* document, const Glib::ustring& user, const Glib::ustring& password, const Glib::ustring& group)
-{
-  if(!document)
-  {
-    std::cerr << G_STRFUNC << ": document is null." << std::endl;
-    return false;
-  }
-
-  if(user.empty())
-  {
-    std::cerr << G_STRFUNC << ": user is empty." << std::endl;
-    return false;
-  }
-
-  if(password.empty())
-  {
-    std::cerr << G_STRFUNC << ": password is  empty." << std::endl;
-    return false;
-  }
-
-  if(group.empty())
-  {
-    std::cerr << G_STRFUNC << ": group is empty." << std::endl;
-    return false;
-  }
-
-  //Create the user:
-  const bool superuser = (group == GLOM_STANDARD_GROUP_NAME_DEVELOPER);
-  const Glib::ustring query_add = build_query_add_user(user, password, superuser);
-  bool test = DbUtils::query_execute_string(query_add);
-  if(!test)
-  {
-    std::cerr << G_STRFUNC << ": CREATE USER failed." << std::endl;
-    return false;
-  }
-
-  //Add it to the group:
-  const Glib::ustring query_add_to_group = build_query_add_user_to_group(group, user);
-  test = DbUtils::query_execute_string(query_add_to_group);
-  if(!test)
-  {
-    std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
-    return false;
-  }
-
-  //Remove any user rights, so that all rights come from the user's presence in the group:
-  Document::type_listTableInfo table_list = document->get_tables();
-
-  for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
-  {
-    const Glib::ustring table_name = (*iter)->get_name();
-    const Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON " + DbUtils::escape_sql_id(table_name) + " FROM " + DbUtils::escape_sql_id(user);
-    const bool test = DbUtils::query_execute_string(strQuery);
-    if(!test)
-      std::cerr << G_STRFUNC << ": REVOKE failed." << std::endl;
-  }
-
-  return true;
-}
-
-bool add_group(const Document* document, const Glib::ustring& group, bool superuser)
-{
-  if(!document)
-  {
-    std::cerr << G_STRFUNC << ": document is null." << std::endl;
-    return false;
-  }
-
-  if(group.empty())
-  {
-    std::cerr << G_STRFUNC << ": group is empty." << std::endl;
-    return false;
-  }
- 
-  const Glib::ustring strQuery = DbUtils::build_query_create_group(group, superuser);
-  //std::cout << "DEBUGCREATE: " << strQuery << std::endl;
-  const bool test = DbUtils::query_execute_string(strQuery);
-  if(!test)
-  {
-    std::cerr << G_STRFUNC << ": CREATE GROUP failed." << std::endl;
-    return false;
-  }
-
-  //Give the new group some sensible default privileges:
-  Privileges priv;
-  priv.m_view = true;
-  priv.m_edit = true;
-
-  const type_vec_strings table_list =
-    get_table_names_from_database(true /* plus system prefs */);
-  for(type_vec_strings::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
-  {
-    if(!Privs::set_table_privileges(group, *iter, priv))
-    {
-      std::cerr << G_STRFUNC << "Privs::set_table_privileges() failed." << std::endl;
-      return false;
-    }
-  }
-
-  //Let them edit the autoincrements too:
-  if(!Privs::set_table_privileges(group, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv))
-  {
-    std::cerr << G_STRFUNC << "Privs::set_table_privileges() failed." << std::endl;
-    return false;
-  }
-
-  return true;
-}
-
-bool remove_user(const Glib::ustring& user)
-{
-  if(user.empty())
-    return false;
-
-  const Glib::ustring strQuery = "DROP USER " + DbUtils::escape_sql_id(user);
-  const bool test = DbUtils::query_execute_string(strQuery);
-  if(!test)
-  {
-    std::cerr << G_STRFUNC << ": DROP USER failed" << std::endl;
-    return false;
-  }
-
-  return true;
-}
-
-bool remove_user_from_group(const Glib::ustring& user, const Glib::ustring& group)
-{
-  if(user.empty() || group.empty())
-    return false;
-
-  const Glib::ustring strQuery = "ALTER GROUP " + DbUtils::escape_sql_id(group) + " DROP USER " + DbUtils::escape_sql_id(user);
-  const bool test = DbUtils::query_execute_string(strQuery);
-  if(!test)
-  {
-    std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
-    return false;
-  }
-
-  return true;
-}
-
 void set_fake_connection()
 {
   //Allow a fake connection, so sqlbuilder_get_full_query() can work:
@@ -2107,6 +2024,41 @@ void set_fake_connection()
   connection_pool->set_fake_connection();
 }
 
+Gnome::Gda::Value get_lookup_value(Document* document, const Glib::ustring& /* table_name */, const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& source_field, const Gnome::Gda::Value& key_value)
+{
+  Gnome::Gda::Value result;
+
+  sharedptr<Field> to_key_field = get_fields_for_table_one_field(document, relationship->get_to_table(), relationship->get_to_field());
+  if(to_key_field)
+  {
+    //Convert the value, in case the from and to fields have different types:
+    const Gnome::Gda::Value value_to_key_field = Conversions::convert_value(key_value, to_key_field->get_glom_type());
+
+    const Glib::ustring target_table = relationship->get_to_table();
+    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+      Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+    builder->select_add_field(source_field->get_name(), target_table );
+    builder->select_add_target(target_table );
+    builder->set_where(
+      builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+        builder->add_field_id(to_key_field->get_name(), target_table),
+        builder->add_expr(value_to_key_field)));
+
+    Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute_select(builder);
+    if(data_model && data_model->get_n_rows())
+    {
+      //There should be only 1 row. Well, there could be more but we will ignore them.
+      result = data_model->get_value_at(0, 0);
+    }
+    else
+    {
+      handle_error();
+    }
+  }
+
+  return result;
+}
+
 } //namespace DbUtils
 
 } //namespace Glom
