@@ -32,22 +32,11 @@ class Privs : public GlomPostgres
 {
 public:
 
-  /** This is apparently undocumented in PostgreSQL,
-   * but if we try to create a user or group
-   * with more characters (or bytes?) than this then
-   * a truncated version of it will be read back.
-   */
-  enum constant
-  {
-     MAX_ROLE_SIZE = 63
-  };
-
   /** Get the groups with access to the database.
    */
   static type_vec_strings get_database_groups();
 
   /** Get users with access to the database.
-   * If the resuilt is empty even when @a group_name is empty then it was not possible to get the list of users, probably due to a permissions problem.
    * @param group_name Get only users in this group.
    */
   static type_vec_strings get_database_users(const Glib::ustring& group_name = Glib::ustring());
@@ -71,7 +60,7 @@ public:
   static Glib::ustring get_default_developer_user_name(Glib::ustring& password);
 
   static Privileges get_table_privileges(const Glib::ustring& group_name, const Glib::ustring& table_name);
-  static bool set_table_privileges(const Glib::ustring& group_name, const Glib::ustring& table_name, const Privileges& privs, bool developer_privs = false);
+  static void set_table_privileges(const Glib::ustring& group_name, const Glib::ustring& table_name, const Privileges& privs, bool developer_privs = false);
 
   static Glib::ustring get_user_visible_group_name(const Glib::ustring& group_name);
 
