@@ -210,16 +210,9 @@ Glib::ustring get_list_of_layout_items_for_display(const LayoutGroup::type_list_
  */
 Glib::ustring get_list_of_layout_items_for_display(const sharedptr<const LayoutGroup>& layout_group);
 
-/** This returns the provided list of layout items,
- * plus the primary key, if the primary key is not already present in the list
+/** Get a string to display to the user, as a representation of a sort order
  */
-LayoutGroup::type_list_const_items get_layout_items_plus_primary_key(const LayoutGroup::type_list_const_items& items, const Document* document, const Glib::ustring& table_name);
-
-//TODO: Avoid the overload just for constness.
-/** This returns the provided list of layout items,
- * plus the primary key, if the primary key is not already present in the list
- */
-LayoutGroup::type_list_items get_layout_items_plus_primary_key(const LayoutGroup::type_list_items& items, const Document* document, const Glib::ustring& table_name);
+Glib::ustring get_list_of_sort_fields_for_display(const FieldFormatting::type_list_sort_fields& sort_fields);
 
 std::string get_temp_file_path(const std::string& prefix = std::string(), const std::string& extension = std::string());
 Glib::ustring get_temp_file_uri(const std::string& prefix = std::string(), const std::string& extension = std::string());
@@ -232,12 +225,6 @@ std::string get_temp_directory_path(const std::string& prefix = std::string());
  */
 Glib::ustring get_temp_directory_uri(const std::string& prefix = std::string());
 
-/** @returns true if the script is OK, or 
- * false if the script uses pygtk2, which would cause a crash,
- * because Glom itself uses GTK+ 3.
- */
-bool script_check_for_pygtk2(const Glib::ustring& script);
-
 } //namespace Utils
 
 } //namespace Glom
