@@ -93,6 +93,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   pack_start(m_hbox_content);
 
   m_FlowTable.signal_field_edited().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_edited) );
+  m_FlowTable.signal_field_choices_changed().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_choices_changed) );
   m_FlowTable.signal_field_open_details_requested().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_open_details_requested) );
   show_all();
 
@@ -735,7 +736,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
         table_name = relationship->get_to_table();
         const Glib::ustring to_field_name = relationship->get_to_field();
         //Get the key field in the other table (the table that we will change)
-        primary_key_field = get_fields_for_table_one_field(table_name, to_field_name); //TODO_Performance.
+        primary_key_field = DbUtils::get_fields_for_table_one_field(document, table_name, to_field_name); //TODO_Performance.
         if(primary_key_field)
         {
           //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
@@ -864,7 +865,6 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     else
     {
       //It is not auto-generated:
-
       if(m_field_primary_key && strFieldName == m_field_primary_key->get_name()) //if it is the primary key that is being edited.
       {
         if(!check_entered_value_for_uniqueness(m_table_name, layout_field, field_value, window))
@@ -893,6 +893,14 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
   } //if(get_primary_key_value_selected().size())
 }
 
+void Box_Data_Details::on_flowtable_field_choices_changed(const sharedptr<const LayoutItem_Field>& layout_field)
+{
+  if(m_ignore_signals)
+    return;
+
+  m_FlowTable.update_choices(layout_field);
+}
+
 void Box_Data_Details::on_userlevel_changed(AppState::userlevels user_level)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
