@@ -98,14 +98,14 @@ Gtk::CellRenderer* create_cell(const sharedptr<const LayoutItem>& layout_item, c
           sharedptr<LayoutItem> unconst = sharedptr<LayoutItem>::cast_const(layout_item); //TODO: Avoid this.
           rendererList->set_layout_item(unconst, table_name);
           bool as_radio_buttons = false; //Can't really be done in a list, so we ignore it.
-          rendererList->set_restrict_values_to_list(
-            formatting.get_choices_restricted(as_radio_buttons));
+          const bool restricted = formatting.get_choices_restricted(as_radio_buttons);
+          rendererList->set_restrict_values_to_list(restricted);
 
           //Set the choices.
           //For related choices, that gets set when the value of a dependent field is set.
           if(formatting.get_has_custom_choices())
           {
-            rendererList->set_choices_fixed( formatting.get_choices_custom() );
+            rendererList->set_choices_fixed( formatting.get_choices_custom(), restricted);
           }
 
           cell = rendererList;
@@ -177,7 +177,7 @@ Gtk::CellRenderer* create_cell(const sharedptr<const LayoutItem>& layout_item, c
     //Use an ellipze to indicate excessive text,
     //so that similar values do not look equal,
     //and to avoid multi-line comments. TODO: Is there a better way to restrict the height? This doesn't actually truncate multilines anyway.
-    g_object_set(cell_text->gobj(), "ellipsize", PANGO_ELLIPSIZE_END, (gpointer)0);
+    cell_text->property_ellipsize() = Pango::ELLIPSIZE_END;
 
     //Restrict the height, to prevent multiline text cells,
     //and to allow TreeView performance optimisation:
@@ -201,7 +201,11 @@ Gtk::CellRenderer* create_cell(const sharedptr<const LayoutItem>& layout_item, c
       const FieldFormatting::type_list_values list_values = item_field->get_formatting_used().get_choices_custom();
       for(FieldFormatting::type_list_values::const_iterator iter = list_values.begin(); iter != list_values.end(); ++iter)
       {
-        pCellRendererList->append_list_item( Conversions::get_text_for_gda_value(item_field->get_glom_type(), *iter, item_field->get_formatting_used().m_numeric_format) );
+        const sharedptr< const ChoiceValue> value = *iter;
+        if(!value)
+          continue;
+
+        pCellRendererList->append_list_item( Conversions::get_text_for_gda_value(item_field->get_glom_type(), value->get_value(), item_field->get_formatting_used().m_numeric_format) );
       }
     }
   }
