@@ -203,7 +203,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
 */
 
 
-void ComboChoicesWithTreeModel::set_choices_fixed(const FieldFormatting::type_list_values& list_values)
+void ComboChoicesWithTreeModel::set_choices_fixed(const FieldFormatting::type_list_values& list_values, bool restricted)
 {
   create_model_non_db(1); //Use a regular ListStore without a dynamic column?
 
@@ -220,14 +220,33 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const FieldFormatting::type_li
     Gtk::TreeModel::Row row = *iterTree;
 
     sharedptr<const LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
-    if(layout_item)
+    if(!layout_item)
+      continue;
+    
+    const sharedptr<ChoiceValue> choicevalue = *iter;
+    if(!choicevalue)
+      continue;
+
+    //Note that this is never a translated version of the value.
+    //This is the original value that will be stored in, or read form, the database.
+    const Gnome::Gda::Value value = choicevalue->get_value();
+    row.set_value(0, value);
+
+    //The text to show in the combo box for the item:
+    Glib::ustring text;
+    if(restricted && choicevalue->is_translatable())
     {
-      const Gnome::Gda::Value value = *iter;
-      row.set_value(0, value);
-      
-      const Glib::ustring text = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format);
-      row.set_value(1, text);
+      //Show the translated text of the value:
+      //This will never be stored in the database:
+      text = choicevalue->get_title();
     }
+    else
+    {
+      text = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), 
+        value, layout_item->get_formatting_used().m_numeric_format);
+    }
+
+    row.set_value(1, text);
   }
 
   //The derived class's (virtual) implementation calls this base method and
@@ -304,6 +323,74 @@ Glib::RefPtr<Gtk::TreeModel> ComboChoicesWithTreeModel::get_choices_model()
   return m_refModel;
 }
 
+void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+{
+  if(!field)
+    return;
+
+  if(!cell)
+    return;
+
+  const Field::glom_field_type type = field->get_glom_type();
+  switch(type)
+  {
+    case(Field::TYPE_BOOLEAN):
+    {
+      Gtk::CellRendererToggle* pDerived = dynamic_cast<Gtk::CellRendererToggle*>(cell);
+      if(pDerived)
+        pDerived->set_active( (value.get_value_type() == G_TYPE_BOOLEAN) && value.get_boolean() );
+
+      break;
+    }
+    case(Field::TYPE_IMAGE):
+    {
+      Gtk::CellRendererPixbuf* pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell);
+      if(pDerived)
+      {
+        const Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
+
+        //Scale it down to a sensible size.
+        //TODO: if(pixbuf)
+        //  pixbuf = Utils::image_scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
+        pDerived->property_pixbuf() = pixbuf;
+      }
+      else
+        std::cerr << "Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
+
+      break;
+    }
+    default:
+    {
+      //TODO: Maybe we should have custom cellcells for time, date, and numbers.
+      Gtk::CellRendererText* pDerived = dynamic_cast<Gtk::CellRendererText*>(cell);
+      if(pDerived)
+      {
+        //std::cout << "debug: " << G_STRFUNC << ": field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
+        const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
+        pDerived->property_text() = text;
+      }
+      else
+      {
+         std::cerr << G_STRFUNC << ": cell has an unexpected type: " << typeid(cell).name() << std::endl;
+      }
+
+      //Show a different color if the value is numeric, if that's specified:
+      if(type == Field::TYPE_NUMERIC)
+      {
+        const Glib::ustring fg_color =
+        field->get_formatting_used().get_text_format_color_foreground_to_use(value);
+        if(!fg_color.empty())
+          pDerived->property_foreground() = fg_color;
+        else
+          //TODO: Remove this when this GTK+ bug is fixed: https://bugzilla.gnome.org/show_bug.cgi?id=667415
+          g_object_set(pDerived->gobj(), "foreground", (const char*)0, (gpointer)0);
+      }
+
+      break;
+    }
+  }
+}
+
 void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& iter, Gtk::CellRenderer* cell, guint model_column_index)
 {
   //std::cout << G_STRFUNC << ": DEBUG: model_column_index=" << model_column_index << std::endl;
@@ -319,76 +406,19 @@ void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& ite
     return;
   }
 
-  if(iter)
-  {
-    const sharedptr<const LayoutItem>& layout_item = m_db_layout_items[model_column_index];
+  if(!iter)
+    return;
 
-    sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
-    if(field)
-    {
-      Gtk::TreeModel::Row treerow = *iter;
-      Gnome::Gda::Value value;
-      treerow->get_value(model_column_index, value);
+  const sharedptr<const LayoutItem>& layout_item = m_db_layout_items[model_column_index];
+  sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
+  if(!field)
+    return;
 
-      const Field::glom_field_type type = field->get_glom_type();
-      switch(type)
-      {
-        case(Field::TYPE_BOOLEAN):
-        {
-          Gtk::CellRendererToggle* pDerived = dynamic_cast<Gtk::CellRendererToggle*>(cell);
-          if(pDerived)
-            pDerived->set_active( (value.get_value_type() == G_TYPE_BOOLEAN) && value.get_boolean() );
+  Gnome::Gda::Value value;
+  Gtk::TreeModel::Row treerow = *iter;
+  treerow->get_value(model_column_index, value);
 
-          break;
-        }
-        case(Field::TYPE_IMAGE):
-        {
-          Gtk::CellRendererPixbuf* pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell);
-          if(pDerived)
-          {
-            const Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
-
-            //Scale it down to a sensible size.
-            //TODO: if(pixbuf)
-            //  pixbuf = Utils::image_scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
-            g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : 0, (gpointer)0);
-          }
-          else
-            std::cerr << "Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
-
-          break;
-        }
-        default:
-        {
-          //TODO: Maybe we should have custom cellcells for time, date, and numbers.
-          Gtk::CellRendererText* pDerived = dynamic_cast<Gtk::CellRendererText*>(cell);
-          if(pDerived)
-          {
-            //std::cout << "debug: " << G_STRFUNC << ": field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
-            const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
-            pDerived->property_text() = text;
-          }
-          else
-          {
-             std::cerr << G_STRFUNC << ": cell has an unexpected type: " << typeid(cell).name() << std::endl;
-          }
-
-          //Show a different color if the value is numeric, if that's specified:
-          if(type == Field::TYPE_NUMERIC)
-          {
-             const Glib::ustring fg_color =
-               field->get_formatting_used().get_text_format_color_foreground_to_use(value);
-             if(!fg_color.empty())
-                 g_object_set(pDerived->gobj(), "foreground", fg_color.c_str(), (gpointer)0);
-             else
-                 g_object_set(pDerived->gobj(), "foreground", (const char*)0, (gpointer)0);
-          }
-
-          break;
-        }
-      }
-    }
-  }
+  set_cell_for_field_value(cell, field, value);
 }
 
 void ComboChoicesWithTreeModel::cell_connect_cell_data_func(Gtk::CellLayout* celllayout, Gtk::CellRenderer* cell, guint model_column_index)
