@@ -117,6 +117,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
     sigc::mem_fun(*this, &Window_PrintLayout_Edit::on_vruler_button_press_event), false);
  
   //Add the ruler widgets to the table at the left and top:
+  //TODO: Use C++ API here:
   Gtk::Grid* grid = 0;
   builder->get_widget("grid_canvas", grid);
   gtk_grid_attach(grid->gobj(), GTK_WIDGET(m_vruler), 
@@ -567,8 +568,8 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
       //Show it on the canvas, at the position:
       if(layout_item)
       {
-        m_layout_item_dropping = 
-          create_canvas_layout_item_and_add(layout_item);
+        m_layout_item_dropping = CanvasLayoutItem::create(layout_item);
+        m_canvas.add_canvas_layout_item(m_layout_item_dropping);
 
         m_layout_item_dropping->snap_position(item_x, item_y);
         m_layout_item_dropping->set_xy(item_x, item_y);
@@ -592,8 +593,8 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
       return;
     }
 
-    Glib::RefPtr<CanvasLayoutItem> item =
-      create_canvas_layout_item_and_add(layout_item);
+    Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+    m_canvas.add_canvas_layout_item(item);
     double item_x = x;
     double item_y = y;
     canvas_convert_from_drag_pixels(item_x, item_y, true /* adjust for scrolling */);
@@ -856,7 +857,8 @@ void Window_PrintLayout_Edit::on_menu_insert_field()
   // Note to translators: This is the default contents of a text item on a print layout: 
   set_default_position(layout_item);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_text()
@@ -864,7 +866,8 @@ void Window_PrintLayout_Edit::on_menu_insert_text()
   sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_TEXT);
   set_default_position(layout_item);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_image()
@@ -874,7 +877,8 @@ void Window_PrintLayout_Edit::on_menu_insert_image()
   //layout_item->set_text(_("text"));
   set_default_position(layout_item);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
@@ -882,7 +886,8 @@ void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
   sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_PORTAL);
   set_default_position(layout_item);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
@@ -899,14 +904,16 @@ void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
   //layout_item->set_text(_("text"));
   //layout_item->set_coordinates(item_x, item_y, item_x + 100, item_y);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_line_vertical()
 {
   sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_LINE_VERTICAL);
 
-  create_canvas_layout_item_and_add(layout_item);
+  Glib::RefPtr<CanvasLayoutItem> item = CanvasLayoutItem::create(layout_item);
+  m_canvas.add_canvas_layout_item(item);
 }
 
 void Window_PrintLayout_Edit::on_menu_insert_create_standard()
@@ -1132,22 +1139,12 @@ void Window_PrintLayout_Edit::on_menu_edit_paste()
     y += offset;
     item->set_print_layout_position(x, y, width, height);
 
-    create_canvas_layout_item_and_add(item);
-
+    Glib::RefPtr<CanvasLayoutItem> canvas_item = 
+      CanvasLayoutItem::create(item);
+    m_canvas.add_canvas_layout_item(canvas_item);
   }
 }
 
-Glib::RefPtr<CanvasLayoutItem> Window_PrintLayout_Edit::create_canvas_layout_item_and_add(const sharedptr<LayoutItem>& layout_item)
-{
-  Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
-  m_canvas.add_canvas_layout_item(canvas_item);
-  canvas_item->set_layout_item(layout_item);
-  
-  //canvas_item->set_outline_visible(m_outline_visibility);
-  
-  return canvas_item;
-}
-
 void Window_PrintLayout_Edit::on_menu_edit_delete()
 {
   while(!m_layout_items_selected.empty())
