@@ -51,7 +51,8 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   m_model_groups = Gtk::ListStore::create(m_model_columns_groups);
   m_model_tables = Gtk::ListStore::create(m_model_columns_tables);
 
-  fill_group_list();
+  //Do this only in load_from_document(), to avoid ever doing it too early, before there is a connection:
+  //fill_group_list();
   //fill_table_list();
 
   m_treeview_groups->set_model(m_model_groups);
@@ -253,18 +254,30 @@ void Dialog_GroupsList::on_button_group_new()
   if(response != Gtk::RESPONSE_OK)
     return;
 
-  if(group_name.empty())
+  if(!group_name.empty())
   {
-    std::cerr << ": group_name is empty" << std::endl;
-    return;
-  }
+    const Glib::ustring strQuery = DbUtils::build_query_create_group(group_name);
+    const bool test = DbUtils::query_execute_string(strQuery);
+    if(!test)
+      std::cout << "debug: " << G_STRFUNC << ": CREATE GROUP failed." << std::endl;
 
-  if(!DbUtils::add_group(get_document(), group_name))
-  {
-    std::cerr << ": DbUtils::add_group() failed." << std::endl;
-  }
+    //Give the new group some sensible default privileges:
+    Privileges priv;
+    priv.m_view = true;
+    priv.m_edit = true;
 
-  fill_group_list();
+    Document::type_listTableInfo table_list = get_document()->get_tables(true /* plus system prefs */);
+
+    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    {
+      Privs::set_table_privileges(group_name, (*iter)->get_name(), priv);
+    }
+
+    //Let them edit the autoincrements too:
+    Privs::set_table_privileges(group_name, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv);
+
+    fill_group_list();
+  }
 }
 
 void Dialog_GroupsList::on_button_group_users()
@@ -288,6 +301,7 @@ void Dialog_GroupsList::on_button_group_users()
       dialog->set_transient_for(*this);
       add_view(dialog); //Give it access to the document.
 
+      dialog->fill_list();
       dialog->set_group(group_name);
 
       Glom::Utils::dialog_run_with_help(dialog);
@@ -334,7 +348,9 @@ Glib::ustring Dialog_GroupsList::get_selected_group() const
 void Dialog_GroupsList::on_treeview_groups_selection_changed()
 {
   //Update the tables list for the currently-selected group:
-  fill_table_list( get_selected_group() );
+  const Glib::ustring group_name = get_selected_group();
+  if(!group_name.empty()) //This can happen when clearing the list, just before filling it, so something real can be selected.
+    fill_table_list(group_name);
 
   enable_buttons();
 }
@@ -373,6 +389,11 @@ void Dialog_GroupsList::fill_group_list()
 
 void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
 {
+  if(group_name.empty())
+  {
+    std::cerr << G_STRFUNC << ": group_name is empty." << std::endl;
+  }
+
   //Fill the model rows:
   m_model_tables->clear();
 
