@@ -59,8 +59,6 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
 
     m_model_users = Gtk::ListStore::create(m_model_columns_users);
 
-    fill_list();
-
     m_treeview_users->set_model(m_model_users);
 
 
@@ -133,7 +131,7 @@ void Dialog_UsersList::on_button_user_remove()
         const Glib::ustring user = row[m_model_columns_users.m_col_name];
         if(!user.empty())
         {
-          DbUtils::remove_user_from_group(user, m_combo_group->get_active_text());
+          remove_user_from_group(user, m_combo_group->get_active_text());
 
           fill_list();
         }
@@ -169,7 +167,7 @@ void Dialog_UsersList::on_button_user_delete()
 
           if(response == Gtk::RESPONSE_OK)
           {
-            DbUtils::remove_user(user); //TODO: Warn about failure when this returns false?
+            remove_user(user);
             fill_list();
           }
         }
@@ -182,15 +180,6 @@ void Dialog_UsersList::on_button_user_delete()
 
 void Dialog_UsersList::on_button_user_add()
 {
-  //Fill it with the list of users:
-  const Privs::type_vec_strings users = Privs::get_database_users();
-  if(users.empty())
-  {
-    Utils::show_ok_dialog(_("Error Retrieving the List of Users"),
-      _("Glom could not get the list of users from the database server. You probably do not have enough permissions. You should be a superuser."), *this, Gtk::MESSAGE_ERROR);
-    return;
-  }
-
   Dialog_ChooseUser* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
@@ -198,7 +187,8 @@ void Dialog_UsersList::on_button_user_add()
 
   dialog->set_transient_for(*this);
 
-  dialog->set_user_list(users);
+  //Fill it with the list of users:
+  dialog->set_user_list( Privs::get_database_users() );
 
   const int response = Glom::Utils::dialog_run_with_help(dialog);
 
@@ -268,7 +258,7 @@ void Dialog_UsersList::on_button_user_new()
   if(response != Gtk::RESPONSE_OK)
     return;
 
-  DbUtils::add_user(get_document(), user, password, m_combo_group->get_active_text() /* group */);
+  add_user(user, password, m_combo_group->get_active_text() /* group */);
   fill_list();
 }
 
