@@ -1,5 +1,23 @@
-#include <gtkmm.h>
-#include <gtksourceviewmm/init.h>
+/* Glom
+ *
+ * Copyright (C) 2010-2011 Murray Cumming
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+ 
 #include <glom/glade_utils.h>
 #include <glom/application.h>
 #include <glom/dialog_existing_or_new.h>
@@ -13,6 +31,7 @@
 #include <glom/import_csv/dialog_import_csv_progress.h>
 #include <glom/mode_data/datawidget/dialog_choose_date.h>
 #include <glom/mode_data/datawidget/dialog_choose_id.h>
+#include <glom/mode_data/datawidget/dialog_new_record.h>
 #include <glom/utility_widgets/dialog_flowtable.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
@@ -38,7 +57,7 @@
 #include <glom/mode_design/dialog_fields.h>
 #include <glom/mode_design/dialog_initial_password.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_fieldslist.h>
-#include <glom/mode_design/layout/layout_item_dialogs/dialog_groupby_sortfields.h>
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_sortfields.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_formatting.h>
 #include <glom/mode_design/script_library/dialog_new_script.h>
 #include <glom/mode_design/script_library/dialog_script_library.h>
@@ -52,8 +71,10 @@
 #include <glom/mode_design/users/dialog_choose_user.h>
 #include <glom/mode_design/users/dialog_user.h>
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
-#include <glom/dialog_progress_creating.h>
 #include <glom/dialog_invalid_data.h>
+#include <gtkmm/builder.h>
+#include <gtkmm/main.h>
+#include <gtksourceviewmm/init.h>
 
 const int GLOM_MAX_WINDOW_WIDTH = 800;
 const int GLOM_MAX_WINDOW_HEIGHT = 600;
@@ -107,10 +128,10 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_Import_CSV_Progress>();
   instantiate_widget<DataWidgetChildren::Dialog_ChooseID>();
   instantiate_widget<DataWidgetChildren::Dialog_ChooseDate>();
+  instantiate_widget<DataWidgetChildren::Dialog_NewRecord>();
   instantiate_widget<Dialog_InvalidData>();
   instantiate_widget<DialogImageLoadProgress>();
   instantiate_widget<DialogImageSaveProgress>();
-  instantiate_widget<Dialog_ProgressCreating>();
 
   //Developer mode UI:
   instantiate_widget<Box_Print_Layouts>();
@@ -131,7 +152,7 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_FieldDefinition>();
   instantiate_widget<Box_Formatting>();
   instantiate_widget<Dialog_FieldsList>();
-  instantiate_widget<Dialog_GroupBy_SortFields>();
+  instantiate_widget<Dialog_SortFields>();
   instantiate_widget<Dialog_Line>();
   instantiate_widget<Dialog_ImageObject>();
   instantiate_widget<Dialog_Notebook>();
